@@ -11,6 +11,7 @@ from math import sqrt, cos, sin, radians
 from typing import Optional, Any, Dict, List, Sequence
 import time
 import struct
+import pytz
 from multiprocessing import Process
 from pathlib import Path
 from functools import partial
@@ -120,6 +121,7 @@ class Ref:  # pylint: disable=too-many-instance-attributes
                 self.start_time = datetime.strptime(val[1].decode('UTF-8'),
                                               '%Y-%m-%dT%H:%M:%S.%fZ')
                 self.start_time = self.start_time.replace(microsecond=0)
+                self.start_time = self.start_time.replace(tzinfo=pytz.UTC)
 
             self.all_refs = bool(self.lat and self.lon and self.start_time)
             if self.all_refs and not self.session_id:
